Class: Sequel::Dataset
- Inherits:
-
Object
- Object
- Sequel::Dataset
- Defined in:
- lib/tqdm/sequel.rb
Overview
In order to use Tqdm with Sequel Datasets, we can simply extend Sequel::Dataset
with the same #with_progress method
Instance Method Summary collapse
-
#with_progress(options = {}) ⇒ Object
(also: #tqdm)
Returns a clone of
selfwhere all calls to#eachand related methods will print an animated progress bar while iterating.
Instance Method Details
#with_progress(options = {}) ⇒ Object Also known as: tqdm
Returns a clone of self where all calls to #each and related methods will print an animated progress bar
while iterating.
21 22 23 |
# File 'lib/tqdm/sequel.rb', line 21 def with_progress( = {}) Tqdm::Decorator.new(self, ).enhance end |